<?php

/**
 * Module: Icon Teaser
 * Display a brief text with a link and use hundreds of built-in icons
 *
 * @author 		SpyroSol
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Icon_Teaser extends SpyropressBuilderModule {

    /**
     * Constructor
     */
    public function __construct() {

        // Widget variable settings
        $this->path = dirname(__FILE__);
        $this->cssclass = 'module-icon-teaser';
        $this->description = __( 'Display a brief text with a link and use of icons.', 'spyropress' );
        $this->id_base = 'spyropress_icon_teaser';
        $this->name = __( 'Icon Teaser', 'spyropress' );

        $this->templates['view-one'] = array( 'view' => 'view-one.php', 'label' =>__( 'Top Icons', 'spyropress' ) );
        $this->templates['view-two'] = array( 'view' => 'view-two.php', 'label' =>__( 'Left Icons', 'spyropress' ) );
        
        // Fields
        $this->fields = array (
             array(

                'label' => __( 'Template', 'spyropress' ),

                'id' => 'template',

                'class' => 'enable_changer section-full',

                'type' => 'select',

                'options' => $this->get_option_templates()

            ),
            
            array(

                'label' => __( 'Number of Columns', 'spyropress' ),

                'id' => 'columns',

                'type' => 'range_slider',

                'std' => 3,

                'max' => 4

            ),
            
            array(

                'label' => __( 'Service', 'spyropress' ),

                'id' => 'services',

                'type' => 'repeater',

                'item_title' => 'heading',

                'fields' => array(
                    array(
                        'label' => __( 'Title', 'spyropress' ),
                        'id' => 'title',
                        'type' => 'text'
                    ),
                    
                    array(
                        'label' => __( 'Upload Icon', 'spyropress' ),
                        'id' => 'icon',
                        'type' => 'upload'
                    ),
        
                    array(
                        'label' => __( 'Content', 'spyropress' ),
                        'id' => 'content',
                        'type' => 'textarea',
                        'rows' => 6
                    ),
                )
            )
           
        );
        
        $this->create_widget();
    }

    function widget( $args, $instance ) {
        
        // extracting info

        extract($args);

        $template = isset( $instance['template'] ) ? $instance['template'] : '';


        include $this->get_view( $template );
    }
    
     function image_teaser_generator( $item, $atts ){
        
        return 
        '<div class="' . esc_attr( $atts['column_class'] ) . '">
              <div class="img-thumbnail"> <img src="'. esc_url( $item['icon'] ) .'" width="85" height="88" alt="secure">
                <div class="caption">
                  <h4>'. esc_html( $item['title'] ) .'</h4>
                  <p>'. esc_html( $item['content'] ) .'</p>
                </div>
            </div>
        </div>';
        
     }
     
     function image_second_teaser_generator( $item, $atts ){
        
        return 
        '<div class="' . esc_attr( $atts['column_class'] ) . '">
            <img src="'. esc_url( $item['icon'] ) .'" width="85" height="88" alt="secure">
            <h4>'. esc_html( $item['title'] ) .'</h4>
            <p>'. esc_html( $item['content'] ) .'</p>                  
        </div>';
        
     }
     

}
spyropress_builder_register_module( 'Spyropress_Module_Icon_Teaser' );