<?php



/**

 * Pricing Table Component

 *

 * @package		SpyroPress

 * @category	Components

 */





class SpyropressPricingTable extends SpyropressComponent {



    private $path;



    function __construct() {



        $this->path = dirname(__FILE__);

        add_action( 'spyropress_register_taxonomy', array( $this, 'register' ) );

        add_shortcode( 'pricing_table',  array( $this, 'shortcode_handler' ) );

    }



    function register() {



        // Init Post Type

        $args = array(

            'public' => false,

            'show_in_admin_bar' => true,

            'supports' => array( 'title' ),

            'has_archive' => false,

            'query_var' => false,

            'menu_icon' => 'dashicons-media-spreadsheet'

        );

        $post_type = new SpyropressCustomPostType( __( 'Pricing Table', 'spyropress' ), 'pricingtable', $args );



        // Shortcode Meta Box

        $instructions = '<p>' . __( 'Display price table anywhere into your posts, pages, custom post types or widgets by using the shortcode below:', 'spyropress' ) . '</p>';

        $instructions .= '<p><code>[pricing_table id={post_id}]</code></p>';



        $sc_fields['shortcode'] = array(

            array(

                'label' => __( 'Shortcode', 'spyropress' ),

                'type' => 'heading',

                'slug' => 'shortcode'

            ),



            array(

                'id' => 'instruction_info',

                'type' => 'raw_info',

                'function' => array( $this, 'set_post_id' ),

                'desc' => $instructions,

            ),

            

            array(

                'label' => __( 'Style', 'spyropress' ),

                'id' => 'style',

                'type' => 'select',

                'class' => 'section-full',

                'options' => array(

                    'one' => __( 'Style One', 'spyropress' ),

                    'two' => __( 'Style Two', 'spyropress' ),

                ),

                'std' => 'one'

            ),



            array(

                'id' => 'column',

                'label' => __( 'Columns', 'spyropress' ),

                'type' => 'select',

                'class' => 'section-full',

                'options' => array(

                    'col-md-4' => __( '3 Columns', 'spyropress' ),

                    'col-md-3' => __( '4 Columns', 'spyropress' ),

                ),

                'std' => 'col-md-4'

            ),

            

            array(

                'label' => __( 'Currency', 'spyropress' ),

                'id' => 'currency',

                'class' => 'section-full',

                'std' => '$'

            ),

            

            array(

                'id' => 'button_text',

                'label' => __( 'Button Text', 'spyropress' ),

                'type' => 'text',

                'class' => 'section-full',

                'std' => 'Sign Up'

            ),

        );



        $post_type->add_meta_box( 'shortcode', __( 'Shortcode & General Settings', 'spyropress' ), $sc_fields, false, false, 'side' );



        // Add Meta Boxes

        $meta_fields['table'] = array(

            array(

                'label' => __( 'Table', 'spyropress' ),

                'type' => 'heading',

                'slug' => 'table'

            ),



            array(

                'label' => __( 'Table', 'spyropress' ),

                'type' => 'repeater',

                'id' => 'tables',

                'item_title' => 'title',

                'hide_label' => true,

                'fields' => array(



                    array(

                        'label' => __( 'Variation', 'spyropress' ),

                        'id' => 'recommended',

                        'type' => 'select',

                        'options' => array(

                            'Recommended' => __( 'Recommended', 'spyropress' ),

                            'plan' => __( 'Plan', 'spyropress' )

                        )

                    ),



                    array(

                        'label' => __( 'Title', 'spyropress' ),

                        'id' => 'title',

                        'type' => 'text'

                    ),

                    

                    array( 'type' => 'row' ),



                        array( 'type' => 'col', 'size' => 6 ),



                            array(

                                'label' => __( 'Price', 'spyropress' ),

                                'id' => 'price',

                                'type' => 'text'

                            ),



                        array( 'type' => 'col_end' ),



                        array( 'type' => 'col', 'size' => 6 ),



                            array(

                                'label' => __( 'Button URL', 'spyropress' ),

                                'id' => 'url',

                                'type' => 'text'

                            ),



                        array( 'type' => 'col_end' ),



                    array( 'type' => 'row_end' ),



                    array(

                        'label' => __( 'Description', 'spyropress' ),

                        'id' => 'description',

                        'type' => 'textarea',

                        'rows' => 4

                    ),



                    array(

                        'label' => __( 'Features', 'spyropress' ),

                        'type' => 'repeater',

                        'id' => 'features',

                        'item_title' => 'title',

                        'fields' => array(

                            array(

                                'label' => __( 'Title', 'spyropress' ),

                                'id' => 'title',

                                'type' => 'text'

                            ),

                            

                            array(

                                'label' => __( 'Feature availablity', 'spyropress' ),

                                'id' => 'feature',

                                'type' => 'select',

                                'options' => array(

                                    'check' => 'Yes',

                                    'cross' => 'No' 

                                )

                            )

                        )

                    )

                )

            )

        );



        $post_type->add_meta_box( 'tables', __( 'Tables', 'spyropress' ), $meta_fields, false, false );

    }



    /**

     * Callback for post_ID for instruction box

     */

    function set_post_id( $output ) {

        global $post;

        return str_replace( '{post_id}', $post->ID, $output );

    }



    /**

     * Shortcode handler

     */

    function shortcode_handler( $atts, $content = '' ) {



        // check

        if( ! isset( $atts['id'] ) || empty( $atts['id'] ) ) return;



        $slider_id = $atts['id'];



        // get slider meta

        $meta = get_post_custom( $slider_id );

        // get slider type

        $columns = maybe_unserialize( $meta['tables'][0] );

        if( empty( $columns ) ) return;



        // get template

        if( isset( $meta['style'] ) )

             $template = maybe_unserialize( $meta['style'][0] );



        $func = "render_table_design_$template";

        return $this->{$func}( $columns, $meta );

    }



    function render_table_design_one( $columns, $meta ) {

        $tables =  '';

        //meta value

        $columns_cls = maybe_unserialize( $meta['column'][0] );

        $currency = maybe_unserialize( $meta['currency'][0] );

        $button_text = maybe_unserialize( $meta['button_text'][0] );

        

        foreach( $columns as $column ) {

            $class = '';$btn_cls = 'btn-success';

            if( isset( $column['recommended'] ) ):

                $class = $column['recommended'];

                $btn_cls = 'btn-danger';

            endif;



            $features = '';

            foreach( $column['features'] as $feature ) {

                $features .= '<li>' . esc_html( $feature['title'] ) . '</li>';

            }



            $tables .= '

            <div class="'. esc_attr( $columns_cls ) .' '. esc_attr( $class ) .' PlanPricing">

              <div class="planName"> <span class="price">' . esc_html( $currency ) . esc_html( $column['price'] ) . '</span>

                <h3>' . esc_html( $column['title'] ) . '</h3>

                <p>' . esc_html( $column['description'] ) . '</p>

              </div>

              <div class="planFeatures">

                <ul>

                    ' . $features . '

                </ul>

              </div>

              <p> <a href="' . esc_url( $column['url'] ) . '" role="button" class="btn btn-lg '. esc_attr( $btn_cls ) .'">' . esc_html( $button_text ) . '</a> </p>

            </div><!-- end span3 -->';

        }

        

        return '<div class="row">' . $tables . '</div>';

    }



    function render_table_design_two( $columns, $meta ) {

        $tables =  '';

        //meta value

        $columns_cls = maybe_unserialize( $meta['column'][0] );

        $currency = maybe_unserialize( $meta['currency'][0] );

        $button_text = maybe_unserialize( $meta['button_text'][0] );

        

        foreach( $columns as $column ) {

            $class = 'pricing';$btn_cls = 'btn-success'; $title = '';

            $title = '<div class="planHead2"><h3>' . esc_html( $column['title'] ) . '</h3></div>';

            if( isset( $column['recommended'] ) ):

                $class = $column['recommended'];

                $btn_cls = 'btn-danger';

                if( $column['recommended'] == 'plan' ):

                    $button = '';
                    
                    $title  = '<div class="planHead1"></div>';
                    
                    $class .= '  CompareList';

               endif;

                

            endif;

            if( $column['recommended'] != 'plan' )

                $button = '<p><a href="' . esc_url( $column['url'] ) . '" role="button" class="btn btn-lg '. esc_attr( $btn_cls ) .'">' . esc_html( $button_text ) . '</a> </p>';

            

            $features = '';

            foreach( $column['features'] as $feature ) {

                if( $feature['feature'] ):

                    $features .='<li><span class="'. esc_attr( $feature['feature'] ) .'"></span></li>';

                else:

                    $features .= '<li>' . esc_html( $feature['title'] ) . '</li>';

                endif;

            }

            

        



            $tables .= '

            <div class="'. esc_attr( $columns_cls ) .' '. $class .'">

                '. $title .'

                <div class="planFeatures">

                    <ul>

                        ' . $features . '

                    </ul>

               </div>

               '. $button .'

            </div><!-- end span3 -->';

        }

        

        return '<div class="row ComparePlans">' . $tables . '</div>';

    }



    function register_module( $modules ) {



        $modules[] = $this->path . '/module/price-table.php';



        return $modules;

    }

}



/**

 * Init the Component

 */

new SpyropressPricingTable();